//
//------
//
//JLOW - Java Libraries fOr Workflow
//
//Author:  Cyril Pestel
//Address: Centre de Donnees astronomiques de Strasbourg
//11 rue de l'Universite
//67000 STRASBOURG
//FRANCE
//Email:   schaaff@astro.u-strasbg.fr, question@simbad.u-strasbg.fr
//
//-------
//
//In accordance with the international conventions about intellectual
//property rights this software and associated documentation files
//(the "Software") is protected. The rightholder authorizes :
//the reproduction and representation as a private copy or for educational
//and research purposes outside any lucrative use,
//subject to the following conditions:
//
//The above copyright notice shall be included.
//
//THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
//OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON INFRINGEMENT,
//LOSS OF DATA, LOSS OF PROFIT, LOSS OF BARGAIN OR IMPOSSIBILITY
//TO USE SUCH SOFWARE. IN NO EVENT SHALL THE RIGHTHOLDER BE LIABLE
//FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
//TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
//THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//For any other exploitation contact the rightholder.
//
//       -----------
//
//Conformement aux conventions internationales relatives aux droits de
//propriete intellectuelle ce logiciel et sa documentation sont proteges.
//Le titulaire des droits autorise :
//la reproduction et la representation a titre de copie privee ou des fins
//d'enseignement et de recherche et en dehors de toute utilisation lucrative.
//Cette autorisation est faite sous les conditions suivantes :
//
//La mention du copyright portee ci-dessus devra etre clairement indiquee.
//
//LE LOGICIEL EST LIVRE "EN L'ETAT", SANS GARANTIE D'AUCUNE SORTE.
//LE TITULAIRE DES DROITS NE SAURAIT, EN AUCUN CAS ETRE TENU CONTRACTUELLEMENT
//OU DELICTUELLEMENT POUR RESPONSABLE DES DOMMAGES DIRECTS OU INDIRECTS
//(Y COMPRIS ET A TITRE PUREMENT ILLUSTRATIF ET NON LIMITATIF,
//LA PRIVATION DE JOUISSANCE DU LOGICIEL, LA PERTE DE DONNEES,
//LE MANQUE A GAGNER OU AUGMENTATION DE COUTS ET DEPENSES, LES PERTES
//D'EXPLOITATION,LES PERTES DE MARCHES OU TOUTES ACTIONS EN CONTREFACON)
//POUVANT RESULTER DE L'UTILISATION, DE LA MAUVAISE UTILISATION
//OU DE L'IMPOSSIBILITE D'UTILISER LE LOGICIEL, ALORS MEME
//QU'IL AURAIT ETE AVISE DE LA POSSIBILITE DE SURVENANCE DE TELS DOMMAGES.
//
//Pour toute autre utilisation contactez le titulaire des droits.
//
package cds.jlow.sample;

import java.awt.*;
import java.util.Hashtable;

import javax.swing.*;

import cds.jlow.client.descriptor.*;
import cds.jlow.client.graph.*;
import cds.jlow.client.util.*;
import cds.jlow.descriptor.*;
import cds.jlow.util.*;

/**
 * 
 * @author Cyril Pestel
 * @version 2.0 beta Copyright CDS 2006 (kickoff 1 April 05)
 */
public class SampleFrame extends JFrame {

	private Registerer register;

	private Jlow wfEditor;

	public SampleFrame() {
		Container content = getContentPane();
		content.setLayout(new BorderLayout());

		register = new Registerer();

		wfEditor = new Jlow(register);
		String idTask = createTaskDescriptor();
		wfEditor.insert(new Point(20,20), idTask);
		
		content.add(wfEditor, "Center");

		setSize(400, 300);
		setLocation(200, 200);
		setTitle("MySample");

		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}
	
	/**
	 * Creates the task RGB color.
	 * 
	 * @return the id of the task
	 */
	public String createTaskDescriptor() {
		//Attributs (view)
		String idAtts = Utils.getIdUnique();
		Attributs attsTask = new Attributs(idAtts, "AttsTask",
				new Color(141, 90, 99, 200), new Dimension(100, 100));
		attsTask.putAtt("border", BorderFactory.createRaisedBevelBorder());
		register.addAtt(attsTask);

		String idTImg = Utils.getIdUnique();
		Attributs typeImg = AttributsFactory.newPortAttributs(idTImg, "Image");
		register.addAtt(typeImg);
		
		//Descriptors
		//Task RGB
		String idDesc = Utils.getIdUnique();
		//Hashtable<String, DefaultModule> mods = new Hashtable<String, DefaultModule>(); //JRE 1.5
		Hashtable mods = new Hashtable();
		mods.put("tostring", new ToStringModule());
		mods.put("tohtml", new ToHtmlModule());
		
		TaskDescriptor desc = new TaskDescriptor(idDesc, "RGB color", mods);
		register.add(desc, idAtts);

		//Ports = 3 images + 1 image
		String idport = Utils.getIdUnique();
		String nameport = "Image 1";
		PortDescriptor port = new PortDescriptor(idport, nameport, IPortDescriptor.INPUT,
				DescriptorFactory.newVariable(Type.STRINGNAME, Type.STRING,
						new String("http://localhost/image1.fits")), mods);
		
		desc.addInputPort(idport);
		register.add(port, idTImg);
		
		idport = Utils.getIdUnique();
		nameport = "Image 2";
		port = new PortDescriptor(idport, nameport, IPortDescriptor.INPUT,
				DescriptorFactory.newVariable(Type.STRINGNAME, Type.STRING,
						new String("http://localhost/image2.fits")), mods);
		
		desc.addInputPort(idport);
		register.add(port, idTImg);
		
		idport = Utils.getIdUnique();
		nameport = "Image 3";
		port = new PortDescriptor(idport, nameport, IPortDescriptor.INPUT,
				DescriptorFactory.newVariable(Type.STRINGNAME, Type.STRING,
						new String("http://localhost/image3.fits")), mods);
		
		desc.addInputPort(idport);
		register.add(port, idTImg);
		
		idport = Utils.getIdUnique();
		nameport = "Image RGB";
		port = new PortDescriptor(idport, nameport, IPortDescriptor.INPUT,
				DescriptorFactory.newVariable(Type.STRINGNAME, Type.STRING), mods);
		
		desc.addOutputPort(idport);
		register.add(port, idTImg);
		
		return idDesc;
	}

	public static void main(String args[]) {
		SampleFrame frame = new SampleFrame();

		frame.setVisible(true);
	}
}
